/// <reference types="node" />
import * as lsProtocol from 'vscode-languageserver-protocol';
import { IPosition, LSPOptions, LSPConnection, TokenInfo } from '.';
import { EventEmitter } from 'events';
declare class LspWsConnection extends EventEmitter implements LSPConnection {
    private socket;
    private documentInfo;
    private serverCapabilities;
    private documentVersion;
    private connection;
    showingTooltip: boolean;
    constructor(options: LSPOptions);
    /**
     * Initialize a connection over a web socket that speaks the LSP protocol
     */
    connect(socket: WebSocket): this;
    sendInitialize(): void;
    sendChange(): void;
    getHoverTooltip(location: IPosition): void;
    getCompletion(location: IPosition, token: TokenInfo, triggerCharacter?: string, triggerKind?: lsProtocol.CompletionTriggerKind): void;
    getDetailedCompletion(completionItem: lsProtocol.CompletionItem): void;
    getSignatureHelp(location: IPosition): void;
    /**
     * Request the locations of all matching document symbols
     */
    getDocumentHighlights(location: IPosition): void;
    /**
     * The characters that trigger completion automatically.
     */
    getLanguageCompletionCharacters(): string[];
    /**
     * The characters that trigger signature help automatically.
     */
    getLanguageSignatureCharacters(): string[];
}
export default LspWsConnection;
